@@ -88,6 +88,10 @@ class FakeRepository(BaseRepository):
         # No need to do an actual pip.Wheel mock here.
         yield
 
+    def copy_ireq_dependencies(self, source, dest):
+        # No state to update.
+        pass
+
 
 class FakeInstalledDistribution(object):
     def __init__(self, line, deps=None):
