@@ -61,7 +61,7 @@ def test_get_hashes_editable_empty_set(from_editable, pypi_repository):
     assert pypi_repository.get_hashes(ireq) == set()
 
 
-@pytest.mark.parametrize("content, content_length", [(b"foo", 3), (b"foobar", 6)])
+@pytest.mark.parametrize(("content", "content_length"), ((b"foo", 3), (b"foobar", 6)))
 def test_open_local_or_remote_file__local_file(tmp_path, content, content_length):
     """
     Test the `open_local_or_remote_file` returns a context manager to a FileStream
@@ -86,14 +86,15 @@ def test_open_local_or_remote_file__directory(tmpdir):
     link = Link(path_to_url(tmpdir.strpath))
     session = Session()
 
-    with pytest.raises(ValueError, match="Cannot open directory for read"):
-        with open_local_or_remote_file(link, session):
-            pass  # pragma: no cover
+    with pytest.raises(
+        ValueError, match="Cannot open directory for read"
+    ), open_local_or_remote_file(link, session):
+        pass  # pragma: no cover
 
 
 @pytest.mark.parametrize(
-    "content, content_length, expected_content_length",
-    [(b"foo", 3, 3), (b"bar", None, None), (b"kek", "invalid-content-length", None)],
+    ("content", "content_length", "expected_content_length"),
+    ((b"foo", 3, 3), (b"bar", None, None), (b"kek", "invalid-content-length", None)),
 )
 def test_open_local_or_remote_file__remote_file(
     tmp_path, content, content_length, expected_content_length
@@ -169,7 +170,7 @@ def test_pip_cache_dir_is_empty(from_line, tmpdir):
 
 
 @pytest.mark.parametrize(
-    "project_data, expected_hashes",
+    ("project_data", "expected_hashes"),
     (
         pytest.param(
             {
@@ -346,3 +347,45 @@ def test_get_project__handles_404(from_line, tmpdir, monkeypatch, pypi_repositor
 
     actual_data = pypi_repository._get_project(ireq)
     assert actual_data is None
+
+
+def test_name_collision(from_line, pypi_repository, make_package, make_sdist, tmpdir):
+    """
+    Test to ensure we don't fail if there are multiple URL-based requirements
+    ending with the same filename where later ones depend on earlier, e.g.
+    https://git.example.com/requirement1/master.zip#egg=req_package_1
+    https://git.example.com/requirement2/master.zip#egg=req_package_2
+    In this case, if req_package_2 depends on req_package_1 we don't want to
+    fail due to issues such as caching the requirement based on filename.
+    """
+    packages = {
+        "test_package_1": make_package("test_package_1", version="0.1"),
+        "test_package_2": make_package(
+            "test_package_2", version="0.1", install_requires=["test-package-1"]
+        ),
+    }
+
+    for pkg_name, pkg in packages.items():
+        pkg_path = str(tmpdir / pkg_name)
+
+        make_sdist(pkg, pkg_path, "--formats=zip")
+
+        os.rename(
+            os.path.join(pkg_path, "{}-{}.zip".format(pkg_name, "0.1")),
+            os.path.join(pkg_path, "master.zip"),
+        )
+
+    name_collision_1 = "file://{dist_path}#egg=test_package_1".format(
+        dist_path=tmpdir / "test_package_1" / "master.zip"
+    )
+    ireq = from_line(name_collision_1)
+    deps = pypi_repository.get_dependencies(ireq)
+    assert len(deps) == 0
+
+    name_collision_2 = "file://{dist_path}#egg=test_package_2".format(
+        dist_path=tmpdir / "test_package_2" / "master.zip"
+    )
+    ireq = from_line(name_collision_2)
+    deps = pypi_repository.get_dependencies(ireq)
+    assert len(deps) == 1
+    assert deps.pop().name == "test-package-1"
